/**
 * @public
 */
export type ErrorDetailMap = Record<string, unknown>;
/**
 * @public
 */
export type ErrorMapLogger = (...args: any[]) => void;
/**
 * @public
 */
export interface ErrorMap<TErrorDetailMap extends ErrorDetailMap> extends Pick<Map<keyof TErrorDetailMap, Error>, 'get' | 'has' | 'delete' | 'clear' | 'size'> {
    /**
     * Error map as messages.
     * @returns string
     *
     * @public
     */
    readonly messages: string;
    /**
     * Set an error by key.
     * @param key - The key.
     * @param error - The error.
     *
     * @public
     */
    set(key: keyof TErrorDetailMap, error: Error): void;
}
/**
 * A factory to create the error map.
 * @param logger - A logger error method reference.
 * @returns A ErrorMap instance.
 *
 * @public
 */
export declare const createErrorMap: <TErrorDetailMap extends ErrorDetailMap>(logger: ErrorMapLogger) => ErrorMap<TErrorDetailMap>;
//# sourceMappingURL=errorMap.d.ts.map